function simDM_plot_eye(signal, time, N_period)
% simDM_plot_eye Plots an eye diagram of the given signal.
% 
%   simDM_plot_eye(signal, time, N_period) plots an eye diagram of the 
%   input signal. The function takes the following inputs:
%   - signal: The input signal to be plotted.
%   - time: The time vector or the period of the signal.
%   - N_period: The number of periods to be plotted.
%
%   If time is not provided or is empty, it defaults to 1.
%   If N_period is not provided or is empty, it defaults to the length of time.
%   If time is a scalar, it is assumed to be the period and a time vector is generated.
%
% This is simulation code provided to help with the development of
% IEEE 802.3dm.
%
% This code is provided for reference to allow independent evaluation
% of the accuracy and applicability of the simulation results shared in
% IEEE 802.3dm presentations by the author.
%
% Written by Ragnar Jonsson, affiliated with Marvell Technology, Inc.
% Version 1.1, January 20th, 2025
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
% OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
% FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
% THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
% LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
% FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
% DEALINGS IN THE SOFTWARE.

    if((nargin < 2) || isempty(time)) % Check if time is provided, if not default to 1
            time = 1;
    end
    if((nargin < 3) || isempty(N_period)) % Check if N_period is provided, if not default to length of time
            N_period = length(time);
    end
    if(length(time) == 1) % If time is a scalar, generate a time vector
            time = [0:N_period-1]*time;
    end
    N_signal = length(signal); % Get the length of the signal
    N_signal = floor(N_signal/N_period)*N_period; % Adjust N_signal to be a multiple of N_period
    
    %%% Plot the eye diagram %%%
    plot(time(1:N_period), reshape(signal(1:N_signal), N_period, N_signal/N_period), 'b');  

end
